@@ -464,7 +464,7 @@ static gboolean button_release_event_cb (GtkWidget *widget, GdkEventButton *bev,
 static gboolean motion_notify_event_cb  (GtkWidget *widget, GdkEventMotion *mev, gpointer user_data);
 static gboolean key_press_event_cb      (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 
-static void expose_event_cb (GtkDrawingArea *drawing_area, GdkEventExpose *eev, gpointer  user_data);
+static gboolean draw_cb (GtkDrawingArea *drawing_area, cairo_t *cr, gpointer  user_data);
 static void size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation, gpointer user_data);
 
 /**
@@ -524,8 +524,8 @@ eog_print_preview_new (void)
 
 /* 	update_relative_sizes (preview); */
 
-	g_signal_connect (G_OBJECT (area), "expose-event",
-			  G_CALLBACK (expose_event_cb), preview);
+	g_signal_connect (G_OBJECT (area), "draw",
+			  G_CALLBACK (draw_cb), preview);
 
 	g_signal_connect (G_OBJECT (area), "motion-notify-event",
 			  G_CALLBACK (motion_notify_event_cb), preview);
@@ -545,22 +545,19 @@ eog_print_preview_new (void)
 	return GTK_WIDGET (preview);
 }
 
-static void
-expose_event_cb (GtkDrawingArea *drawing_area,
-		 GdkEventExpose *eev,
+static gboolean
+draw_cb (GtkDrawingArea *drawing_area,
+		 cairo_t *cr,
 		 gpointer  user_data)
 {
 	GtkWidget *widget;
 	EogPrintPreviewPrivate *priv;
-	cairo_t *cr;
 
 	widget = GTK_WIDGET (drawing_area);
 	priv = EOG_PRINT_PREVIEW (user_data)->priv;
 
 	update_relative_sizes (EOG_PRINT_PREVIEW (user_data));
 
-	cr = gdk_cairo_create (widget->window);
-
 	eog_print_preview_draw (EOG_PRINT_PREVIEW (user_data), cr);
 
 	if (cairo_status (cr) != CAIRO_STATUS_SUCCESS) {
@@ -568,9 +565,8 @@ expose_event_cb (GtkDrawingArea *drawing_area,
 			 cairo_status_to_string (cairo_status (cr)));
 	}
 
-	cairo_destroy (cr);
-
-	gdk_window_get_pointer (widget->window, NULL, NULL, NULL);
+	gdk_window_get_pointer (gtk_widget_get_window (widget), NULL, NULL, NULL);
+	return TRUE;
 }
 
 /**
@@ -587,14 +583,13 @@ get_current_image_coordinates (EogPrintPreview *preview,
 			       gint *x0, gint *y0)
 {
 	EogPrintPreviewPrivate *priv;
-	gint p_width, p_height;
+	GtkAllocation allocation;
 
 	priv = preview->priv;
-	p_width = priv->area->allocation.width;
-	p_height = priv->area->allocation.height;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->area), &allocation);
 
-	*x0 = (gint)((1 - priv->image_x_align)*priv->l_rmargin +  priv->image_x_align*(p_width - priv->r_rmargin - priv->r_width));
-	*y0 = (gint)((1 - priv->image_y_align)*priv->t_rmargin +  priv->image_y_align*(p_height - priv->b_rmargin - priv->r_height));
+	*x0 = (gint)((1 - priv->image_x_align)*priv->l_rmargin +  priv->image_x_align*(allocation.width - priv->r_rmargin - priv->r_width));
+	*y0 = (gint)((1 - priv->image_y_align)*priv->t_rmargin +  priv->image_y_align*(allocation.height - priv->b_rmargin - priv->r_height));
 }
 
 /**
@@ -632,17 +627,18 @@ create_image_scaled (EogPrintPreview *preview)
 	EogPrintPreviewPrivate *priv = preview->priv;
 
 	if (!priv->image_scaled) {
-		gint a_width, a_height, i_width, i_height;
+		gint i_width, i_height;
+		GtkAllocation allocation;
 
-		GtkWidget *area = priv->area;
-		a_width = area->allocation.width;
-		a_height = area->allocation.height;
+		gtk_widget_get_allocation (priv->area, &allocation);
 		i_width = gdk_pixbuf_get_width (priv->image);
 		i_height = gdk_pixbuf_get_height (priv->image);
 
-                if ((i_width > a_width) || (i_height > a_height)) {
+                if ((i_width > allocation.width) ||
+		    (i_height > allocation.height)) {
 			gdouble scale;
-			scale = MIN ((gdouble) a_width/i_width, (gdouble)a_height/i_height);
+			scale = MIN ((gdouble) allocation.width/i_width,
+				     (gdouble) allocation.height/i_height);
 			priv->image_scaled = gdk_pixbuf_scale_simple (priv->image,
 								      i_width*scale,
 								      i_height*scale,
@@ -704,6 +700,7 @@ create_surface_from_pixbuf (GdkPixbuf *pixbuf)
   guchar *gdk_pixels = gdk_pixbuf_get_pixels (pixbuf);
   int gdk_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
   int n_channels = gdk_pixbuf_get_n_channels (pixbuf);
+  int cairo_stride;
   guchar *cairo_pixels;
   cairo_format_t format;
   cairo_surface_t *surface;
@@ -715,10 +712,11 @@ create_surface_from_pixbuf (GdkPixbuf *pixbuf)
   else
     format = CAIRO_FORMAT_ARGB32;
 
-  cairo_pixels = g_malloc (4 * width * height);
+  cairo_stride = cairo_format_stride_for_width (format, width);
+  cairo_pixels = g_malloc (height * cairo_stride);
   surface = cairo_image_surface_create_for_data ((unsigned char *)cairo_pixels,
 						 format,
-						 width, height, 4 * width);
+						 width, height, cairo_stride);
   cairo_surface_set_user_data (surface, &key,
 			       cairo_pixels, (cairo_destroy_func_t)g_free);
 
@@ -775,7 +773,7 @@ create_surface_from_pixbuf (GdkPixbuf *pixbuf)
 	}
 
       gdk_pixels += gdk_rowstride;
-      cairo_pixels += 4 * width;
+      cairo_pixels += cairo_stride;
     }
 
   return surface;
@@ -866,19 +864,19 @@ key_press_event_cb (GtkWidget   *widget,
 	delta = 0;
 
 	switch (event->keyval) {
-	case GDK_Left:
+	case GDK_KEY_Left:
 		property = "image-x-align";
 		delta = -0.01;
 		break;
-	case GDK_Right:
+	case GDK_KEY_Right:
 		property = "image-x-align";
 		delta = 0.01;
 		break;
-	case GDK_Up:
+	case GDK_KEY_Up:
 		property = "image-y-align";
 		delta = -0.01;
 		break;
-	case GDK_Down:
+	case GDK_KEY_Down:
 		property = "image-y-align";
 		delta = 0.01;
 		break;
@@ -911,18 +909,17 @@ motion_notify_event_cb (GtkWidget      *widget,
 {
 	EogPrintPreviewPrivate *priv = EOG_PRINT_PREVIEW (user_data)->priv;
 	gdouble dx, dy;
-	gint p_width, p_height;
+	GtkAllocation allocation;
 
 	if (priv->grabbed) {
 		dx = event->x - priv->cursorx;
 		dy = event->y - priv->cursory;
 
-		p_width  = widget->allocation.width;
-		p_height = widget->allocation.height;
+		gtk_widget_get_allocation (widget, &allocation);
 
 		/* Make sure the image stays inside the margins */
 
-		priv->image_x_align += (dx + priv->r_dx)/(p_width  - priv->r_width - priv->l_rmargin - priv->r_rmargin);
+		priv->image_x_align += (dx + priv->r_dx)/(allocation.width  - priv->r_width - priv->l_rmargin - priv->r_rmargin);
 		if (priv->image_x_align < 0. || priv->image_x_align > 1.) {
 			priv->image_x_align = CLAMP (priv->image_x_align, 0., 1.);
 			priv->r_dx += dx;
@@ -930,7 +927,7 @@ motion_notify_event_cb (GtkWidget      *widget,
 		else
 			priv->r_dx = 0;
 
-		priv->image_y_align += (dy + priv->r_dy)/(p_height - priv->r_height - priv->t_rmargin - priv->b_rmargin);
+		priv->image_y_align += (dy + priv->r_dy)/(allocation.height - priv->r_height - priv->t_rmargin - priv->b_rmargin);
 		if (priv->image_y_align < 0. || priv->image_y_align > 1.) {
 			priv->image_y_align = CLAMP (priv->image_y_align, 0., 1.);
 			priv->r_dy += dy;
@@ -954,10 +951,12 @@ motion_notify_event_cb (GtkWidget      *widget,
 		  	GdkCursor *cursor;
 			cursor = gdk_cursor_new_for_display (gtk_widget_get_display (widget),
 							     GDK_FLEUR);
-			gdk_window_set_cursor (widget->window, cursor);
+			gdk_window_set_cursor (gtk_widget_get_window (widget),
+					       cursor);
 			gdk_cursor_unref (cursor);
 		} else {
-			gdk_window_set_cursor (widget->window, NULL);
+			gdk_window_set_cursor (gtk_widget_get_window (widget),
+					       NULL);
 		}
 	}
 	return FALSE;
@@ -986,9 +985,9 @@ size_allocate_cb (GtkWidget *widget,
 static void
 eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 {
-	gint w_width, w_height;
 	EogPrintPreviewPrivate *priv;
 	GtkWidget *area;
+	GtkAllocation allocation;
 	gint x0, y0;
 	GtkStyle *style;
 	gboolean has_focus;
@@ -996,16 +995,15 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 	priv = preview->priv;
 	area = priv->area;
 
-	has_focus = GTK_WIDGET_HAS_FOCUS (area);
+	has_focus = gtk_widget_has_focus (area);
 
-	style = area->style;
+	style = gtk_widget_get_style (area);
 
-	w_width = area->allocation.width;
-	w_height = area->allocation.height;
+	gtk_widget_get_allocation (area, &allocation);
 
 	/* draw the page */
  	gdk_cairo_set_source_color (cr, &style->white);
- 	cairo_rectangle (cr, 0, 0, w_width, w_height);
+ 	cairo_rectangle (cr, 0, 0, allocation.width, allocation.height);
  	cairo_fill (cr);
 
 	/* draw the page margins */
@@ -1013,8 +1011,8 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 	cairo_set_line_width (cr, 0.1);
 	cairo_rectangle (cr,
 			 priv->l_rmargin, priv->t_rmargin,
-			 w_width - priv->l_rmargin - priv->r_rmargin,
-			 w_height - priv->t_rmargin - priv->b_rmargin);
+			 allocation.width - priv->l_rmargin - priv->r_rmargin,
+			 allocation.height - priv->t_rmargin - priv->b_rmargin);
 	cairo_stroke (cr);
 
 	get_current_image_coordinates (preview, &x0, &y0);
@@ -1051,9 +1049,9 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 	}
 
 	if (has_focus) {
-		gtk_paint_focus (style, area->window, GTK_STATE_NORMAL,
-				 NULL, NULL, NULL,
-				 0, 0, w_width, w_height);
+		gtk_paint_focus (style, cr,
+				 GTK_STATE_NORMAL, NULL, NULL,
+				 0, 0, allocation.width, allocation.height);
 	}
 }
 
@@ -1061,7 +1059,7 @@ static void
 update_relative_sizes (EogPrintPreview *preview)
 {
 	EogPrintPreviewPrivate *priv;
-	gint p_width;
+	GtkAllocation allocation;
 	gint i_width, i_height;
 
 	priv = preview->priv;
@@ -1073,9 +1071,9 @@ update_relative_sizes (EogPrintPreview *preview)
 		i_width = i_height = 0;
 	}
 
-	p_width = priv->area->allocation.width;
+	gtk_widget_get_allocation (priv->area, &allocation);
 
-	priv->p_scale = (gfloat)p_width / (priv->p_width * 72.0);
+	priv->p_scale = (gfloat) allocation.width / (priv->p_width * 72.0);
 
 	priv->r_width  = (gint) i_width  * priv->i_scale * priv->p_scale;
 	priv->r_height = (gint) i_height * priv->i_scale * priv->p_scale;
