@@ -58,10 +58,7 @@ eog_statusbar_init (EogStatusbar *statusbar)
 	statusbar->priv = EOG_STATUSBAR_GET_PRIVATE (statusbar);
 	priv = statusbar->priv;
 
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar), TRUE);
-
 	priv->img_num_statusbar = gtk_statusbar_new ();
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (priv->img_num_statusbar), FALSE);
 	gtk_widget_set_size_request (priv->img_num_statusbar, 100, 10);
 	gtk_widget_show (priv->img_num_statusbar);
 
@@ -112,6 +109,10 @@ eog_statusbar_set_image_number (EogStatusbar *statusbar,
 
 	gtk_statusbar_pop (GTK_STATUSBAR (statusbar->priv->img_num_statusbar), 0);
 
+	/* Hide number display if values don't make sense */
+	if (G_UNLIKELY (num <= 0 || tot <= 0))
+		return;
+
 	/* Translators: This string is displayed in the statusbar.
 	 * The first token is the image number, the second is total image
 	 * count.
@@ -146,12 +147,3 @@ eog_statusbar_set_progress (EogStatusbar *statusbar,
 		gtk_widget_show (statusbar->priv->img_num_statusbar);
 	}
 }
-
-void
-eog_statusbar_set_has_resize_grip (EogStatusbar *statusbar, gboolean has_resize_grip)
-{
-	g_return_if_fail (EOG_IS_STATUSBAR (statusbar));
-
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar),
-					   has_resize_grip);
-}
